@@ -114,9 +114,9 @@ def test_get_recipe_tiddler_list_filtered_one():
     response, content = http.request('http://our_test_domain:8001/recipes/long/tiddlers.txt?select=title:tiddler8',
             method='GET')
 
-    assert response['last-modified'] == 'Fri, 23 May 2008 03:03:00 GMT'
     assert response['status'] == '200'
-    assert content == 'tiddler8'
+    assert response['last-modified'] == 'Fri, 23 May 2008 03:03:00 GMT'
+    assert content == 'tiddler8\n'
 
 def test_get_recipe_tiddler_list_filtered_empty():
     http = httplib2.Http()
