@@ -1,5 +1,5 @@
 """
-A module containing the Bag class.
+A module containing the Policy class.
 """
 
 
@@ -25,21 +25,28 @@ class UserRequiredError(PermissionsError):
 
 class Policy(object):
     """
-    A container for information about the
-    contraints on a bag. A bag is something that
-    contains tiddlers. We need to be able to say
-    who can do what to do those tiddlers. We also
-    need to be able to say who can manage those
-    constraints.
+    A container for information about the contraints on a bag or recipe.
+    Both are containers of tiddlers. We need to be able to say who can
+    do what to do those tiddlers. We also need to be able to say who can
+    manage those constraints.
 
     The init parameters represent a default policy.
-    The default policy should really come from
-    server configuration. Then we can declare this
-    installation as open-ish, or closed-ish.
+
+    There are six constraints plus one identifying atrribute (owner).
+    The constraints are listed below with descriptions of what is allowed
+    if the constraint passes.
+
+    read -- View this entity in lists. View the contained entities.
+    write -- Edit the contained entities that already exist.
+    create -- Create new entities in the container.
+    delete -- Remove a contained entity.
+    manage -- Change the policy itself.
+    accept -- Accept the entity into the container without requiring
+              validation.
     """
 
-    attributes = ['read', 'write', 'create', 'delete', 'manage', 'accept',
-            'owner']
+    attributes = [u'read', u'write', u'create', u'delete', u'manage', u'accept',
+            u'owner']
 
     def __init__(self, owner=None,
             read=None, write=None, create=None, delete=None,
@@ -106,6 +113,10 @@ class Policy(object):
         raise ForbiddenError('%s may not %s' % (user_sign, constraint))
 
     def user_perms(self, usersign):
+        """
+        For this policy return a list of constraints for which
+        this usersign passes.
+        """
         perms = ['read', 'write', 'create', 'delete']
         matched_perms = []
         for perm in perms:
@@ -167,20 +178,24 @@ def _no_constraint(info_list):
 
 
 def _role_valid(roles, role_list):
-    # if there is an intersection between the users roles and any roles
-    # in the constraint, return true
+    """
+    Return true if there is an intersection between the users roles
+    and any roles in the constraint.
+    """
     if [role for role in roles if role in role_list]:
         return True
     return False
 
 
 def _user_valid(user_sign, user_list):
-    # always allow if the constraint is ANY
+    """
+    If the user_sign is in the constraint or the constraint value
+    is ANY, return true.
+    """
     if _single_value_set(user_list, u'ANY'):
         if user_sign != u'GUEST':
             return True
 
-    # if the user is in the constraint list, return true
     if user_sign in user_list:
         return True
 
