@@ -8,14 +8,15 @@ import urllib
 
 import simplejson
 
+from tiddlyweb.model.collections import Tiddlers
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.policy import PermissionsError
 from tiddlyweb.model.recipe import Recipe
-from tiddlyweb.model.tiddler import Tiddler
+from tiddlyweb.model.tiddler import Tiddler, current_timestring
 from tiddlyweb.store import \
         NoTiddlerError, NoBagError, NoRecipeError, StoreMethodNotImplemented
-from tiddlyweb.serializer import Serializer, TiddlerFormatError
-from tiddlyweb.util import sha
+from tiddlyweb.serializer import Serializer, TiddlerFormatError, NoSerializationError
+from tiddlyweb.util import sha, pseudo_binary
 from tiddlyweb.web.http import \
         HTTP404, HTTP415, HTTP412, HTTP409, HTTP400, HTTP304
 from tiddlyweb import control
@@ -31,7 +32,7 @@ def get(environ, start_response):
     containing bag.
     """
     tiddler = _determine_tiddler(environ,
-            control.determine_tiddler_bag_from_recipe)
+            control.determine_bag_from_recipe)
     return _send_tiddler(environ, start_response, tiddler)
 
 
@@ -40,7 +41,7 @@ def get_revisions(environ, start_response):
     Get the list of revisions for this tiddler.
     """
     tiddler = _determine_tiddler(environ,
-            control.determine_tiddler_bag_from_recipe)
+            control.determine_bag_from_recipe)
     return _send_tiddler_revisions(environ, start_response, tiddler)
 
 
@@ -50,7 +51,7 @@ def delete(environ, start_response):
     delete means is up to the store.
     """
     tiddler = _determine_tiddler(environ,
-            control.determine_tiddler_bag_from_recipe)
+            control.determine_bag_from_recipe)
     return _delete_tiddler(environ, start_response, tiddler)
 
 
@@ -61,7 +62,7 @@ def post_revisions(environ, start_response):
     That collection is known as a TiddlerChronicle.
     """
     tiddler = _determine_tiddler(environ,
-            control.determine_tiddler_bag_from_recipe)
+            control.determine_bag_from_recipe)
     return _post_tiddler_revisions(environ, start_response, tiddler)
 
 
@@ -83,7 +84,6 @@ def _check_bag_constraint(environ, bag, constraint):
     try:
         store = environ['tiddlyweb.store']
         usersign = environ['tiddlyweb.usersign']
-        bag.skinny = True
         bag = store.get(bag)
         bag.policy.allows(usersign, constraint)
     except (PermissionsError), exc:
@@ -146,19 +146,33 @@ def _determine_tiddler(environ, bag_finder):
     # doing filter checks.
     if environ['REQUEST_METHOD'] == 'PUT':
         length, content_type = _length_and_type(environ)
-
-        if content_type != 'text/plain' and content_type != 'application/json':
-            tiddler.type = content_type
-
         content = environ['wsgi.input'].read(int(length))
 
-        if not tiddler.type:
+        try:
+            # XXX HACK! We don't want to decode content unless
+            # the serializer has a as_tiddler. We should be able
+            # to just rely on NoSerializationError, but we need
+            # to call the method to do that, and to call the method we
+            # need to decode the string...
             serialize_type = web.get_serialize_type(environ)[0]
             serializer = Serializer(serialize_type, environ)
             serializer.object = tiddler
-            serializer.from_string(content.decode('utf-8'))
-        else:
-            tiddler.text = content
+            if hasattr(serializer.serialization, 'as_tiddler'):
+                try:
+                    serializer.from_string(content.decode('utf-8'))
+                except TiddlerFormatError, exc:
+                    raise HTTP400('unable to put tiddler: %s' % exc)
+            else:
+                raise NoSerializationError
+        except NoSerializationError:
+            tiddler.type = content_type
+            if pseudo_binary(tiddler.type):
+                try:
+                    tiddler.text = content.decode('utf-8')
+                except UnicodeDecodeError, exc:
+                    raise HTTP400('unable decode tiddler: %s', exc)
+            else:
+                tiddler.text = content
 
     recipe_name = environ['wsgiorg.routing_args'][1].get('recipe_name', None)
     if recipe_name:
@@ -230,10 +244,13 @@ def _store_tiddler_revisions(environ, content, tiddler):
     store = environ['tiddlyweb.store']
     serializer = Serializer('json', environ)
     serializer.object = tiddler
-    for json_tiddler in reversed(json_tiddlers):
-        json_string = simplejson.dumps(json_tiddler)
-        serializer.from_string(json_string.decode('utf-8'))
-        store.put(tiddler)
+    try:
+        for json_tiddler in reversed(json_tiddlers):
+            json_string = simplejson.dumps(json_tiddler)
+            serializer.from_string(json_string.decode('utf-8'))
+            store.put(tiddler)
+    except NoTiddlerError, exc:
+        raise HTTP400('Unable to store tiddler revisions: %s', exc)
 
 
 def _length_and_type(environ):
@@ -300,6 +317,7 @@ def _put_tiddler(environ, start_response, tiddler):
         user = environ['tiddlyweb.usersign']['name']
         if not user == 'GUEST':
             tiddler.modifier = user
+        tiddler.modified = current_timestring()
 
         try:
             _check_bag_constraint(environ, bag, 'accept')
@@ -413,7 +431,11 @@ def _send_tiddler(environ, start_response, tiddler):
 
     bag = Bag(tiddler.bag)
     # this will raise 403 if constraint does not pass
-    _check_bag_constraint(environ, bag, 'read')
+    try:
+        _check_bag_constraint(environ, bag, 'read')
+    except NoBagError, exc:
+        raise HTTP404('%s not found, no bag %s, %s' %
+                (tiddler.title, tiddler.bag, exc))
 
     try:
         tiddler = store.get(tiddler)
@@ -443,17 +465,19 @@ def _send_tiddler(environ, start_response, tiddler):
     else:
         return content
 
+
 def _get_tiddler_content(environ, tiddler):
     """
     Extract the content of the tiddler, either straight up if
     the content is not considered text, or serialized if it is
     """
-    serializers = environ['tiddlyweb.config']['serializers']
-    default_serialize_type = serializers['default'][0]
+    config = environ['tiddlyweb.config']
+    default_serializer = config['default_serializer']
+    default_serialize_type = config['serializers'][default_serializer][0]
     serialize_type, mime_type = web.get_serialize_type(environ)
     extension = environ.get('tiddlyweb.extension')
 
-    if _not_wikitext(tiddler, environ['tiddlyweb.config']):
+    if _not_wikitext(tiddler, config):
         if (serialize_type == default_serialize_type or
                 mime_type.startswith(tiddler.type) or
                 extension == 'html'):
@@ -478,9 +502,9 @@ def _not_wikitext(tiddler, config):
     system. In this context wikitext means something
     that can be rendered.
     """
-    return (tiddler.type and # type is set
-            tiddler.type != 'None' and # type is not None stringified
-            tiddler.type not in # type is not id'd as wikitext by config
+    return (tiddler.type and  # type is set
+            tiddler.type != 'None' and  # type is not None stringified
+            tiddler.type not in  # type is not id'd as wikitext by config
             config['wikitext.type_render_map'])
 
 
@@ -490,25 +514,23 @@ def _send_tiddler_revisions(environ, start_response, tiddler):
     """
     store = environ['tiddlyweb.store']
 
-    tmp_bag = Bag('tmp', tmpbag=True, revbag=True)
+    tiddlers = Tiddlers(store=store)
+    tiddlers.is_revisions = True
+    recipe = tiddler.recipe
     try:
         for revision in store.list_tiddler_revisions(tiddler):
             tmp_tiddler = Tiddler(title=tiddler.title, bag=tiddler.bag)
             tmp_tiddler.revision = revision
-            try:
-                tmp_tiddler = store.get(tmp_tiddler)
-            except NoTiddlerError, exc:
-                # If a particular revision is not present in the store.
-                raise HTTP404('tiddler %s at revision % not found, %s' %
-                        (tiddler.title, revision, exc))
-            tmp_bag.add_tiddler(tmp_tiddler)
+            if recipe:
+                tmp_tiddler.recipe = recipe
+            tiddlers.add(tmp_tiddler)
     except NoTiddlerError, exc:
         # If a tiddler is not present in the store.
         raise HTTP404('tiddler %s not found, %s' % (tiddler.title, exc))
     except StoreMethodNotImplemented:
         raise HTTP400('no revision support')
 
-    return send_tiddlers(environ, start_response, tmp_bag)
+    return send_tiddlers(environ, start_response, tiddlers=tiddlers)
 
 
 def _new_tiddler_etag(tiddler):
@@ -529,9 +551,9 @@ def _tiddler_etag(environ, tiddler):
     try:
         mime_type = web.get_serialize_type(environ)[1]
         mime_type = mime_type.split(';', 1)[0].strip()
-    except TypeError:
-        mime_type = ''
+    except (TypeError, AttributeError):
+        mime_type = tiddler.type or ''
     username = environ.get('tiddlyweb.usersign', {}).get('name', '')
-    hash = sha('%s:%s' % (username, mime_type)).hexdigest()
+    digest = sha('%s:%s' % (username, mime_type)).hexdigest()
     return str('"%s/%s/%s;%s"' % (web.encode_name(tiddler.bag),
-        web.encode_name(tiddler.title), tiddler.revision, hash))
+        web.encode_name(tiddler.title), tiddler.revision, digest))
