@@ -1,6 +1,5 @@
 """
-General utility routines shared by various
-web related modules.
+General utility routines shared by various web related modules.
 """
 
 import Cookie
@@ -17,9 +16,10 @@ def get_serialize_type(environ):
     Look in the environ to determine which serializer
     we should use for this request.
     """
+    config = environ['tiddlyweb.config']
     accept = environ.get('tiddlyweb.type')[:]
     ext = environ.get('tiddlyweb.extension')
-    serializers = environ['tiddlyweb.config']['serializers']
+    serializers = config['serializers']
     serialize_type, mime_type = None, None
 
     if type(accept) == str:
@@ -34,7 +34,11 @@ def get_serialize_type(environ):
     if not serialize_type:
         if ext:
             raise HTTP415('%s type unsupported' % ext)
-        serialize_type, mime_type = serializers['default']
+        # If we are a PUT and we haven't found a serializer, don't
+        # state a default as that makes no sense.
+        if environ['REQUEST_METHOD'] == 'GET':
+            default_serializer = config['default_serializer']
+            serialize_type, mime_type = serializers[default_serializer]
     return serialize_type, mime_type
 
 
@@ -65,12 +69,15 @@ def http_date_from_timestamp(timestamp):
     Turn a modifier or created tiddler timestamp
     into a proper formatted HTTP date.
     """
-    try:
-        timestamp_datetime = datetime(*(time.strptime(timestamp,
-            '%Y%m%d%H%M')[0:6]))
-    except ValueError:
-        timestamp_datetime = datetime(*(time.strptime(timestamp,
-            '%Y%m%d%H%M%S')[0:6]))
+    if len(timestamp) > 4:
+        try:
+            timestamp_datetime = datetime(*(time.strptime(timestamp,
+                '%Y%m%d%H%M')[0:6]))
+        except ValueError:
+            timestamp_datetime = datetime(*(time.strptime(timestamp,
+                '%Y%m%d%H%M%S')[0:6]))
+    else:
+        timestamp_datetime = datetime.utcnow()
     return timestamp_datetime.strftime('%a, %d %b %Y %H:%M:%S GMT')
 
 
@@ -86,7 +93,8 @@ def datetime_from_http_date(http_datestring):
     return http_datetime
 
 
-def make_cookie(name, value, mac_key=None, path=None, expires=None):
+def make_cookie(name, value, mac_key=None, path=None,
+        expires=None, httponly=True):
     """
     Create a cookie string, optionally with a MAC, path and
     expires value. Expires is in seconds.
@@ -107,7 +115,10 @@ def make_cookie(name, value, mac_key=None, path=None, expires=None):
     if expires:
         cookie[name]['max-age'] = expires
 
-    return cookie.output(header='').lstrip().rstrip()
+    output = cookie.output(header='').lstrip().rstrip()
+    if httponly:
+        output += '; httponly'
+    return output
 
 
 def server_base_url(environ):
@@ -164,7 +175,7 @@ def escape_attribute_value(text):
     """
     try:
         return text.replace('"', '&quot;')
-    except AttributeError: # value might be None
+    except AttributeError:  # value might be None
         return text
 
 
